// Dataset
const data = [
  { year: 2000, cost: 488700 },
  { year: 2001, cost: 260089 },
  { year: 2002, cost: 766087 },
  { year: 2003, cost: 595598 },
  { year: 2004, cost: 260099 },
  { year: 2005, cost: 336535 },
  { year: 2006, cost: 371790 },
  { year: 2007, cost: 956009 },
  { year: 2008, cost: 279948 },
  { year: 2008, cost: 422683 },
  { year: 2009, cost: 144209 },
  { year: 2010, cost: 375078 },
  { year: 2011, cost: 416632 },
  { year: 2012, cost: 316773 },
  { year: 2013, cost: 469292 },
];

// Set the dimensions and margins of the graph
const margin = { top: 10, right: 30, bottom: 30, left: 50 },
  width = 460 - margin.left - margin.right,
  height = 400 - margin.top - margin.bottom;

// Append the svg object to the body of the page
const svg = d3
  .select('body')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Add X axis --> it is a date format
const x = d3
  .scaleLinear()
  .domain(
    d3.extent(data, function (d) {
      return d.year;
    }),
  )
  .range([0, width]);
svg
  .append('g')
  .attr('transform', 'translate(0,' + height + ')')
  .call(d3.axisBottom(x));

// Add Y axis
const y = d3
  .scaleLinear()
  .domain([
    0,
    d3.max(data, function (d) {
      return +d.cost;
    }),
  ])
  .range([height, 0]);
svg.append('g').call(d3.axisLeft(y));

// Add the area
svg
  .append('path')
  .datum(data)
  .attr('fill', '#cce5df')
  .attr('stroke', '#69b3a2')
  .attr('stroke-width', 1.5)
  .attr(
    'd',
    d3
      .area()
      .x(function (d) {
        return x(d.year);
      })
      .y0(height)
      .y1(function (d) {
        return y(d.cost);
      }),
  );
